const path = require("path");
const fs = require("fs-extra");

/**
 * Extract header for a post
 * @param  {Object} post
 * @return {string}
 */
module.exports = async post => {
  const source = path.join(process.cwd(), "_data");
  let header = "";
  try {
    let tags = await fs.readJSON(path.join(source, `tags.json`));
    let cats = await fs.readJSON(path.join(source, `categories.json`));
    let users = await fs.readJSON(path.join(source, `users.json`));
    let author = users.filter(u => u.id === post.author);
    header = `---
title: "${post.title.rendered}"
date: ${post.date}
author: ${author.length ? author[0].name : "Unknown"}
tags: 
${tags
  .filter(res => post.tags.includes(res.id))
  .map(t => `  - "${t.name}"`)
  .join("\n") || ""}
categories: 
${cats
  .filter(res => post.categories.includes(res.id))
  .map(t => `  - "${t.name}"`)
  .join("\n") || ""}
---
`;
  } catch (err) {
    console.log(`Error building header for ${post.id}`, err);
    process.exit(1);
  }

  return header;
};
