const path = require("path");
const fs = require("fs-extra");
const header = require("./header");
const media = require("./media");
const turndown = require("./turndown");
const ora = require("ora");

module.exports = async () => {
  const source = path.join(process.cwd(), "_data");
  const posts = await fs.readJSON(path.join(source, `posts.json`));
  const progress = ora("Processing posts");
  Object.keys(posts).forEach(async key => {
    const post = posts[key];
    progress.text(`Writing post: ${post.id}...`);
    const dest = path.join(process.cwd(), "content", "blog", post.slug);
    let content = turndown(post.content.rendered);
    const head = await header(post);
    content = head + content;
    await fs.ensureDir(dest);
    await fs.outputFile(path.join(dest, "index.md"), content);
    await media(dest, post.id);
  });
  progress.succeed("Finished writing posts");
};
