const fs = require("fs-extra");
const path = require("path");
const ora = require("ora");
const walker = require("./walker");

/**
 * Scrap and write API responses to data folder
 * @param  {string} url
 */
module.exports = async url => {
  const leafs = ["posts", "users", "categories", "tags"];
  const dest = path.join(process.cwd(), "_data");
  const progress = ora("Creating data directory...");
  await fs.ensureDir(dest);
  leafs.forEach(async leaf => {
    progress.text(`Fetching ${leaf}...`);
    const result = await walker(url, leaf);
    await fs.writeJSON(path.join(dest, `${leaf}.json`), result);
    progress.succeed(`Finished fetching ${leaf}`);
    // scrap attached media for a post
    if (leaf === "posts") {
      progress.text(`Fetching images metadata for post: ${leaf.id}...`);
      const result = await walker(url, `media?parent=${leaf.id}`);
      await fs.writeJSON(path.join(dest, `media-${leaf.id}.json`), result);
      progress.succeed(`Finished fetching images for post : ${leaf.id}`);
    }
  });
};
