const TurnDown = require("turndown");

// Turndown Part
const td = new TurnDown({
  headingStyle: "atx",
  codeBlockStyle: "fenced",
  blankReplacement(content, node) {
    var gistURL = node.getAttribute("data-gist");
    return gistURL ? `\n\`gist:${gistURL}\`\n` : "";
  }
});

// Pre tag => PrismJS for gatsby plugin
td.addRule("pre-tags", {
  filter: "pre",
  replacement(value) {
    // Remove Escape Characters from String
    // created by td.prototype.escape
    // Unfortenately node is private in Turndown.js
    const content = value.replace(/\\/g, "");

    // Check if there is a Newline character to make the comment inline
    return content.split("\n").length > 1
      ? `\n\`\`\`\n${content}\n\`\`\`\n`
      : ` \`${content}\` `;
  }
});

// Code tag => PrismJS for gatsby plugin
td.addRule("code-tags", {
  filter: "code",
  replacement(content) {
    return content.split("\n").length > 1
      ? `\n\`\`\`\n${content}\n\`\`\`\n`
      : ` \`${content}\` `;
  }
});

td.addRule("images", {
  filter: "img",
  replacement: function(content, node) {
    var alt = node.alt || "";
    var src = node.getAttribute("src") || "";
    var title = node.title || "";
    var titlePart = title ? ' "' + title + '"' : "";
    src = src.split("?")[0].substring(src.lastIndexOf("/") + 1);
    return src ? "![" + alt + "]" + "(" + "./" + src + titlePart + ")" : "";
  }
});

// Strong tag fixes
td.addRule("strong", {
  filter: "strong",
  replacement(content) {
    return `**${content.trim()}**`;
  }
});

td.addRule("removal", {
  filter: node =>
    /(sharedaddy|crayon-main|crayon-toolbar|crayon-tools)/.test(
      node.className
    ) || node.nodeName === "style",
  replacement(content, node) {
    return "";
  }
});

td.addRule("crayon", {
  filter: node =>
    (node.nodeName = "div" && /crayon-syntax/.test(node.className)),
  replacement(content, node) {
    return `\n\`\`\`\n${content.trim()}\n\`\`\`\n`;
  }
});

td.addRule("su-box", {
  filter: node => (node.nodeName = "div" && /su-box/.test(node.className)),
  replacement(content, node) {
    const title = node.firstChild.textContent;
    const body = node.lastChild.textContent;
    return `<box title="${title}">${body}</box>`;
  }
});

td.addRule("style", {
  filter: "style",
  replacement(content, node) {
    return "";
  }
});

module.exports = td.turndown;
