const ora = require("ora");
const fetch = require("node-fetch");

/**
 * Walk through all the pages of a route
 * @param  {string} url
 * @param  {string} route
 */
module.exports = async (url, route) => {
  const result = [];
  let pageCount = 1;
  try {
    const res = await fetch(`${url}/${route}?per_page=100`);
    if (res.status === 200) {
      pageCount = res.headers.get("x-wp-totalpages");
      const progress = ora(`Fetching ${route} 1/${pageCount}...`);
      result.push(...(await res.json()));
      for (let i = 2; i <= pageCount; i++) {
        const res = await fetch(
          `${url}/${route}?per_page=100&page=${pageCount}`
        );
        if (res.status === 200) {
          progress.text(`Fetching ${route} ${i}/${pageCount}...`);
          result.push(...(await res.json()));
        } else {
          ora.fail(`Failed to fetch ${route}: ${res.status}`);
          process.exit(1);
        }
      }
    } else {
      ora.fail(`Failed to fetch ${route}: ${res.status}`);
      process.exit(1);
    }
  } catch (e) {
    console.log(`Error fetching ${route} \\n ${e}`);
    process.exit(1);
  }
  return result;
};
